ComplexRDA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexRDA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexRDA.__init__
      ~ComplexRDA.components
      ~ComplexRDA.components_amplitude
      ~ComplexRDA.components_phase
      ~ComplexRDA.compute
      ~ComplexRDA.correlation_coefficients_X
      ~ComplexRDA.correlation_coefficients_Y
      ~ComplexRDA.cross_correlation_coefficients
      ~ComplexRDA.deserialize
      ~ComplexRDA.fit
      ~ComplexRDA.fraction_variance_X_explained_by_X
      ~ComplexRDA.fraction_variance_Y_explained_by_X
      ~ComplexRDA.fraction_variance_Y_explained_by_Y
      ~ComplexRDA.get_params
      ~ComplexRDA.get_serialization_attrs
      ~ComplexRDA.heterogeneous_patterns
      ~ComplexRDA.homogeneous_patterns
      ~ComplexRDA.inverse_transform
      ~ComplexRDA.load
      ~ComplexRDA.predict
      ~ComplexRDA.save
      ~ComplexRDA.scores
      ~ComplexRDA.scores_amplitude
      ~ComplexRDA.scores_phase
      ~ComplexRDA.serialize
      ~ComplexRDA.squared_covariance_fraction
      ~ComplexRDA.transform
   
   

   
   
   